<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>About</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-family:&apos;Sans Serif&apos;; font-size:12pt; font-style:normal;&quot;&gt;&lt;p style=&quot;margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Version: %1&lt;br/&gt;Qt version: %5&lt;br/&gt;Drumstick version: %6&lt;br/&gt;Build date: %2&lt;br/&gt;Build time: %3&lt;br/&gt;Compiler: %4&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutClass</name>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Drumstick Metronome&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;https://kmetronome.sourceforge.io&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://kmetronome.sourceforge.io&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2002-2021, &lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net?subject=VMPK&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Pedro Lopez-Cabanillas &amp;lt;plcl@users.sf.net&amp;gt;&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;This program is free software; you can redistribute it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, see &lt;/span&gt;&lt;a href=&quot;https://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrumGrid</name>
    <message>
        <source>Rows:</source>
        <translation type="unfinished">Zeilen:</translation>
    </message>
    <message>
        <source>Use this button to add new rows (sounds) to the current pattern definition</source>
        <translation type="unfinished">Dieser Knopf fügt der aktuellen Definition des Rhythmusschemas neue Zeilen (Töne) hinzu</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">Hinzufügen</translation>
    </message>
    <message>
        <source>Use this button to remove the selected row (sound) from the pattern definition</source>
        <translation type="unfinished">Dieser Knopf  entfernt die ausgewählte Zeile (Töne) aus der Definition des Rhythmusschemas</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Entfernen</translation>
    </message>
    <message>
        <source>Beats:</source>
        <translation type="unfinished">Taktzahl:</translation>
    </message>
    <message>
        <source>Highligh the grid columns while playing</source>
        <translation type="unfinished">Markiere die Gitterspalten während der Wiedergabe</translation>
    </message>
    <message>
        <source>Highlight
Columns</source>
        <translation type="unfinished">Markiere
Spalten</translation>
    </message>
    <message>
        <source>This is the current beat number</source>
        <translation type="unfinished">Dies ist die aktuelle Anzahl Grundschläge</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation type="unfinished">Rhythmusschema:</translation>
    </message>
    <message>
        <source>Type a new name and press the &quot;Save&quot; button to create a new pattern, or choose an existing pattern from the drop-down list.</source>
        <translation type="unfinished">Geben Sie einen neuen Namen ein und drücken Sie den Knopf &quot;Speichern&quot;, um ein neues Rhythmusschemas zu erstellen, oder  wählen Sie ein vorhandenes Schema aus der Aufklappliste.</translation>
    </message>
    <message>
        <source>This button stores the current pattern definition with the name given</source>
        <translation type="unfinished">Dieser Knopf speichert die aktuelle Definition des Rhythmusschemas mit dem gegebenen Namen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Speichern</translation>
    </message>
    <message>
        <source>This button deletes the current pattern definition</source>
        <translation type="unfinished">Dieser Knopf entfernt die aktuelle Definition des Rhythmusschemas</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Entfernen</translation>
    </message>
    <message>
        <source>Number of beats per measure (bar)</source>
        <translation type="unfinished">Anzahl Grundschläge pro Takt</translation>
    </message>
    <message>
        <source>This is the beat length for the pattern column.</source>
        <translation type="unfinished">Dies ist die Dauer des Grundschlags für die Spalte des Rhythmusschemas.</translation>
    </message>
    <message>
        <source>Whole</source>
        <translation type="obsolete">Ganze</translation>
    </message>
    <message>
        <source>Half</source>
        <translation type="obsolete">Halbe</translation>
    </message>
    <message>
        <source>Quarter</source>
        <translation type="obsolete">Viertel</translation>
    </message>
    <message>
        <source>Eighth</source>
        <translation type="obsolete">Achtel</translation>
    </message>
    <message>
        <source>Sixteenth</source>
        <translation type="obsolete">Sechzehntel</translation>
    </message>
    <message>
        <source>Thirty-Second</source>
        <translation type="obsolete">Zweiundreissigstel</translation>
    </message>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="obsolete">Vierundsechzigstel</translation>
    </message>
    <message>
        <source>This button starts playing the current pattern</source>
        <translation type="unfinished">Dieser Knopf startet die Wiedergabe des Rhythmusschemas</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Wiedergabe</translation>
    </message>
    <message>
        <source>This button stops the playback</source>
        <translation type="unfinished">Dieser Knopf beendet die Wiedergabe</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished">Stopp</translation>
    </message>
    <message>
        <source>QPM: quarters per minute</source>
        <translation type="unfinished">QPM: Tempo (in Viertel pro Minute)</translation>
    </message>
    <message>
        <source>QPM:</source>
        <comment>Quarters per Minute</comment>
        <translation type="unfinished">QPM:</translation>
    </message>
    <message>
        <source>This is the current tempo in quarters per minute</source>
        <translation type="unfinished">Dies ist das aktuelle Tempo in Viertel pro Minute</translation>
    </message>
    <message>
        <source>Drag the slider handle to change the tempo, in quarters per minute</source>
        <translation type="unfinished">Ziehen Sie den Schieberegler um das Tempo zu ändern, in Viertel pro Minute</translation>
    </message>
    <message>
        <source>This is the pattern table, beats as columns and sounds as rows</source>
        <translation type="unfinished">Dies ist die Tabelle des Rhythmusschemas, Grundschläge als Spalten und Töne als Zeilen</translation>
    </message>
    <message>
        <source>Pattern Editor</source>
        <translation type="unfinished">Editor für Rhythmusschema</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished">
            </translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">
            </translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished">Rhythmusschema</translation>
    </message>
    <message>
        <source>Remove Pattern</source>
        <translation type="unfinished">Rhythmusschema entfernen</translation>
    </message>
    <message>
        <source>Do you want to remove the current pattern?</source>
        <translation type="unfinished">Möchten Sie das aktuelle Rhythmusschema entfernen?</translation>
    </message>
    <message>
        <source>Sample Pattern</source>
        <comment>name of an automatically created pattern</comment>
        <translation type="unfinished">Muster für Rhythmusschema</translation>
    </message>
    <message>
        <source>Insert Pattern Row</source>
        <translation type="unfinished">Zeile in Rhythmusschema einfügen</translation>
    </message>
    <message>
        <source>Drum Key:</source>
        <translation type="unfinished">Schlagzeug Taste:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select one, and only one row</source>
        <translation type="unfinished">Bitte wählen Sie eine, und nur eine Zeile aus</translation>
    </message>
    <message>
        <source>Remove Row</source>
        <translation type="unfinished">Zeile entfernen</translation>
    </message>
    <message>
        <source>Do you want to remove the selected pattern row?</source>
        <translation type="unfinished">Möchten Sie die ausgewählte Zeile des Rhythmusschemas entfernen?</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&amp;Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KMetroPreferences</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished">Einstellungen</translation>
    </message>
</context>
<context>
    <name>KMetroPreferencesBase</name>
    <message>
        <source>If this checkbox is activated, the the program will remember the connections for the input and output ports, and try to reconnect them at program startup.</source>
        <translation type="unfinished">Aktivieren Sie dieses Ankreuzfeld, damit das Programm sich an den Eingangs- und Ausgangs-Port erinnert, und diese beim nächsten Programmstart wieder verbindet.</translation>
    </message>
    <message>
        <source>Automatic ports connection on startup</source>
        <translation type="unfinished">Automatische Verbindung der Ports beim Start</translation>
    </message>
    <message>
        <source>Optional input port conn:</source>
        <translation type="unfinished">Opt.Verbindung Eingangs-Port:</translation>
    </message>
    <message>
        <source>This is the optional connection for the MIDI IN port.</source>
        <translation type="unfinished">Dies ist die optionale Verbindung für den MIDI Eingangs-Port</translation>
    </message>
    <message>
        <source>Output port connection:</source>
        <translation type="unfinished">Verbindung für Ausgabe-Port:</translation>
    </message>
    <message>
        <source>This is the mandatory connection for the MIDI OUT port</source>
        <translation type="unfinished">Dies ist die notwendige Verbindung für den MIDI Ausgabe-Port</translation>
    </message>
    <message>
        <source>Output instrument:</source>
        <translation type="unfinished">Ausgabe Instrument:</translation>
    </message>
    <message>
        <source>This is the definition of the instrument connected to the MIDI OUT port</source>
        <translation type="unfinished">Dies ist die Definition des Instrumentes das mit dem MIDI Ausgabe-Port verbunden ist</translation>
    </message>
    <message>
        <source>Bank:</source>
        <translation type="unfinished">Bank:</translation>
    </message>
    <message>
        <source>This is the Bank of the selected MIDI program</source>
        <translation type="unfinished">Dies ist die Bank des ausgewählten MIDI Programms</translation>
    </message>
    <message>
        <source>Channel:</source>
        <translation type="unfinished">Kanal:</translation>
    </message>
    <message>
        <source>This is the MIDI channel, between 1 and 16. 
General MIDI uses the channel 10 for percussion sounds.</source>
        <translation type="unfinished">Dies ist der MIDI Kanal, zwischen 1 und 16. 
Allgemeines MIDI braucht den Kanal 10 für das Schlagzeug.</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation type="unfinished">Programm:</translation>
    </message>
    <message>
        <source>This is the MIDI program</source>
        <translation type="unfinished">Dies ist das MIDI Programm</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="unfinished">Auflösung:</translation>
    </message>
    <message>
        <source>This is the MIDI time resolution (number of ticks in a quarter note)</source>
        <translation type="unfinished">Dies ist die MIDI Zeitauflösung (Anzahl Ticks in einer Viertel Note)</translation>
    </message>
    <message>
        <source>Weak note:</source>
        <translation type="unfinished">Schwache Note:</translation>
    </message>
    <message>
        <source>This is the sound of the weak notes for the automatic patterns</source>
        <translation type="unfinished">Dies ist die Lautstärke der schwachen Note im automatischen Rhythmusschema</translation>
    </message>
    <message>
        <source>Note duration:</source>
        <translation type="unfinished">Dauer der Note:</translation>
    </message>
    <message>
        <source>This is the note duration in ticks, when using NOTE OFF events</source>
        <translation type="unfinished">Dies ist die Dauer der Note in Anzahl Ticks, wenn NOTE OFF Ereignisse benutzt werden.</translation>
    </message>
    <message>
        <source>Strong note:</source>
        <translation type="unfinished">Starke Note:</translation>
    </message>
    <message>
        <source>This is the sound of the strong notes for the automatic patterns</source>
        <translation type="unfinished">Dies ist die Lautstärke der starken Note im automatischen Rhythmusschema</translation>
    </message>
    <message>
        <source>Optional setting to send NOTE OFF events</source>
        <translation type="unfinished">Optionale Einstellung zum Senden von NOTE OFF Ereignissen</translation>
    </message>
    <message>
        <source>Send NOTE OFF events</source>
        <translation type="unfinished">Sende NOTE OFF Ereignisse</translation>
    </message>
    <message>
        <source>Forced Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal Icon Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt Style:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KMetronome</name>
    <message>
        <source>Fatal error from the ALSA sequencer. This usually happens when the kernel doesn&apos;t have ALSA support, or the device node (/dev/snd/seq) doesn&apos;t exists, or the kernel module (snd_seq) is not loaded. Please check your ALSA/MIDI configuration. Returned error was: %1</source>
        <translation type="unfinished">Schwerer Fehler im ALSA-Sequenzer. Dies geschieht meist, wenn der Kernel kein ALSA unterstützt, oder das Gerät (/dev/snd/seq) nicht existiert, oder das Kernel-Modul (snd_seq) nicht geladen ist. Bitte überprüfen Sie Ihre ALSA/MIDI Konfiguration. Zurückgegebener Fehler war: %1</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Fehler</translation>
    </message>
    <message>
        <source>Import Patterns</source>
        <translation type="unfinished">Rhythmusschema importieren</translation>
    </message>
    <message>
        <source>Pattern Files (*.pat)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Patterns</source>
        <translation type="unfinished">Rhythmusschema exportieren</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation type="unfinished">Tempo</translation>
    </message>
    <message>
        <source>Enter new Tempo:</source>
        <translation type="unfinished">Neues Tempo eingeben:</translation>
    </message>
    <message>
        <source>Automatic</source>
        <comment>the pattern is created automatically</comment>
        <translation type="unfinished">Automatisch</translation>
    </message>
    <message>
        <source>Language Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The language for this application is going to change to %1. Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KMetronomeWindow</name>
    <message>
        <source>Drumstick Metronome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This button starts playing the rhythm pattern</source>
        <translation type="unfinished">Dieser Knopf startet die Wiedergabe des Rhythmusschemas</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Wiedergabe</translation>
    </message>
    <message>
        <source>This button stops playing the rhythm pattern</source>
        <translation type="unfinished">Dieser Knopf stoppt die Wiedergabe des Rhythmusschemas</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished">Stopp</translation>
    </message>
    <message>
        <source>This button opens the configuration window</source>
        <translation type="unfinished">Dieser Knopf öffnet den Einrichtungsdialog</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Einstellungen</translation>
    </message>
    <message>
        <source>This button opens the pattern editor</source>
        <translation type="unfinished">Dieser Knopf öffnet den Editor für das Rhythmusschema</translation>
    </message>
    <message>
        <source>Patterns</source>
        <translation type="unfinished">Rhythmusschema</translation>
    </message>
    <message>
        <source>This button exits the program</source>
        <translation type="unfinished">Dieser Knopf beendet das Programm</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Beenden</translation>
    </message>
    <message>
        <source>Number of measures (bars) and beats played from beginning</source>
        <translation type="unfinished">Anzahl Noten (Takte) und Schläge seit Beginn der Wiedergabe</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation type="unfinished">Rhythmusschema:</translation>
    </message>
    <message>
        <source>This is the pattern definition to play, either &quot;Automatic&quot; or a custom defined one.</source>
        <translation type="unfinished">Dies ist die Definition des Rhythmusschemas für die Wiedergabe, entweder &quot;Automatisch&quot; oder Benutzerdefiniert.</translation>
    </message>
    <message>
        <source>Beats/Bar:</source>
        <translation type="unfinished">Taktzahl:</translation>
    </message>
    <message>
        <source>This is the number of beats for each measure (bar).
Values are from 1 to 32.
It is the numerator of the time signature specification.</source>
        <translation type="unfinished">Dies ist die Anzahl Grundschläge für jeden Takt.
Die Werte sind von 1 bis 32.
Dies ist der Zähler der Taktart-Spezifikation.</translation>
    </message>
    <message>
        <source>Beat Length:</source>
        <translation type="unfinished">Länge Grundschlag.</translation>
    </message>
    <message>
        <source>This is the beat length.
Values mean 1, 2, 4, 8, 16, 32 and 64.
It is the denominator in the time signature specification.</source>
        <translation type="unfinished">Dies ist die Dauer des Grundschlags.
Die Werte sind 1, 2, 4, 8, 16, 32 und 64.
Es ist der Nenner der Taktart-Spezifikation.</translation>
    </message>
    <message>
        <source>Whole</source>
        <translation type="obsolete">Ganze</translation>
    </message>
    <message>
        <source>Half</source>
        <translation type="obsolete">Halbe</translation>
    </message>
    <message>
        <source>Quarter</source>
        <translation type="obsolete">Viertel</translation>
    </message>
    <message>
        <source>Eighth</source>
        <translation type="obsolete">Achtel</translation>
    </message>
    <message>
        <source>Sixteenth</source>
        <translation type="obsolete">Sechzehntel</translation>
    </message>
    <message>
        <source>Thirty-Second</source>
        <translation type="obsolete">Zweiundreissigstel</translation>
    </message>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="obsolete">Vierundsechzigstel</translation>
    </message>
    <message>
        <source>Weak</source>
        <comment>weak notes MIDI velocity</comment>
        <translation type="unfinished">Schwach</translation>
    </message>
    <message>
        <source>Strong</source>
        <comment>strong notes MIDI velocity</comment>
        <translation type="unfinished"> Stark</translation>
    </message>
    <message>
        <source>Volume</source>
        <comment>audio volume level</comment>
        <translation type="unfinished">Volumen</translation>
    </message>
    <message>
        <source>Pan</source>
        <comment>audio panning</comment>
        <translation type="unfinished">Balance</translation>
    </message>
    <message>
        <source>This is the velocity of the weak notes in the automatic rhythm pattern (all of them, except the first one)</source>
        <translation type="unfinished">Dies ist die Lautstärke der schwachen Noten im Rhythmusschema (alle von ihnen, ausser der ersten)</translation>
    </message>
    <message>
        <source>This is the velocity of the strong note in the automatic rhythm pattern (the first one)</source>
        <translation type="unfinished">Dies ist die Lautstärke der starken Note im Rhythmusschema (die erste)</translation>
    </message>
    <message>
        <source>This is the MIDI volume control (CC7)</source>
        <translation type="unfinished">Dies ist die MIDI Lautstärkenregelung (CC7)</translation>
    </message>
    <message>
        <source>This is the MIDI pan control (CC10)</source>
        <translation type="unfinished">Dies ist die MIDI Balance Steuerung (CC10)</translation>
    </message>
    <message>
        <source>This is the musical name of the tempo value</source>
        <translation type="unfinished">Dies ist der musikalische Name des Tempos</translation>
    </message>
    <message>
        <source>The current &lt;i&gt;tempo&lt;/i&gt; value</source>
        <translation type="unfinished">Der aktuelle Wert für das &lt;i&gt;Tempo&lt;/i&gt;</translation>
    </message>
    <message>
        <source>Tempo (in quarters per minute)</source>
        <translation type="unfinished">Tempo (in Viertel pro Minute)</translation>
    </message>
    <message>
        <source>This slider changes the &lt;i&gt;tempo&lt;/i&gt;, or speed of the rhythm.
Values are 25 to 250 quarters per minute (&lt;i&gt;Maelzel Metronome units&lt;/i&gt;).</source>
        <translation type="unfinished">Dieser Schieberegler ändert das &lt;i&gt;Tempo&lt;/i&gt;, oder Geschwindigkeit des Rhythmus.
Die Werte sind von 25 bis 250 Viertel pro Minute (&lt;i&gt;Maelzel Metronom Einheiten&lt;/i&gt;).</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Patterns</source>
        <translation type="unfinished">Rhythmusschema importieren</translation>
    </message>
    <message>
        <source>Export Patterns</source>
        <translation type="unfinished">Rhythmusschema exportieren</translation>
    </message>
    <message>
        <source>Play/Stop</source>
        <translation type="unfinished">Wiedergabe/Stopp</translation>
    </message>
    <message>
        <source>Edit Patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>about</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Action Buttons</source>
        <translation type="unfinished">Aktionsknopf anzeigen</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>about Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help Contents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Whole</source>
        <translation type="unfinished">Ganze</translation>
    </message>
    <message>
        <source>Half</source>
        <translation type="unfinished">Halbe</translation>
    </message>
    <message>
        <source>Quarter</source>
        <translation type="unfinished">Viertel</translation>
    </message>
    <message>
        <source>Eight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sixteenth</source>
        <translation type="unfinished">Sechzehntel</translation>
    </message>
    <message>
        <source>Thirty-Second</source>
        <translation type="unfinished">Zweiundreissigstel</translation>
    </message>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="unfinished">Vierundsechzigstel</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cakewalk Instrument Definition File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SequencerAdapter</name>
    <message>
        <source>No connection</source>
        <translation type="unfinished">Keine Verbindung</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:101</name>
    <message>
        <source>Drag the slider handle to change the tempo, in quarters per minute</source>
        <translation type="vanished">Ziehen Sie den Schieberegler um das Tempo zu ändern, in Viertel pro Minute</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:104</name>
    <message>
        <source>MIDI Metronome</source>
        <translation type="vanished">MIDI Metronom</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:107</name>
    <message>
        <source>This button starts playing the rhythm pattern</source>
        <translation type="vanished">Dieser Knopf startet die Wiedergabe des Rhythmusschemas</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:110</name>
    <message>
        <source>Play</source>
        <translation type="vanished">Wiedergabe</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:113</name>
    <message>
        <source>This button stops playing the rhythm pattern</source>
        <translation type="vanished">Dieser Knopf stoppt die Wiedergabe des Rhythmusschemas</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:116</name>
    <message>
        <source>Stop</source>
        <translation type="vanished">Stopp</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:119</name>
    <message>
        <source>This button opens the configuration window</source>
        <translation type="vanished">Dieser Knopf öffnet den Einrichtungsdialog</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:12</name>
    <message>
        <source>Save</source>
        <translation type="vanished">Speichern</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:122</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">Einstellungen</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:125</name>
    <message>
        <source>This button opens the pattern editor</source>
        <translation type="vanished">Dieser Knopf öffnet den Editor für das Rhythmusschema</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:128</name>
    <message>
        <source>Patterns</source>
        <translation type="vanished">Rhythmusschema</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:131</name>
    <message>
        <source>This button exits the program</source>
        <translation type="vanished">Dieser Knopf beendet das Programm</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:134</name>
    <message>
        <source>Quit</source>
        <translation type="vanished">Beenden</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:137</name>
    <message>
        <source>Number of measures (bars) and beats played from beginning</source>
        <translation type="vanished">Anzahl Noten (Takte) und Schläge seit Beginn der Wiedergabe</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:140</name>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Rhythmusschema:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:143</name>
    <message>
        <source>This is the pattern definition to play, either &quot;Automatic&quot; or a custom defined one.</source>
        <translation type="vanished">Dies ist die Definition des Rhythmusschemas für die Wiedergabe, entweder &quot;Automatisch&quot; oder Benutzerdefiniert.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:146</name>
    <message>
        <source>Beats/Bar:</source>
        <translation type="vanished">Taktzahl:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:149</name>
    <message>
        <source>This is the number of beats for each measure (bar).
Values are from 1 to 32.
It is the numerator of the time signature specification.</source>
        <translation type="vanished">Dies ist die Anzahl Grundschläge für jeden Takt.
Die Werte sind von 1 bis 32.
Dies ist der Zähler der Taktart-Spezifikation.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:15</name>
    <message>
        <source>This button deletes the current pattern definition</source>
        <translation type="vanished">Dieser Knopf entfernt die aktuelle Definition des Rhythmusschemas</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:154</name>
    <message>
        <source>Beat Length:</source>
        <translation type="vanished">Länge Grundschlag.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:157</name>
    <message>
        <source>This is the beat length.
Values mean 1, 2, 4, 8, 16, 32 and 64.
It is the denominator in the time signature specification.</source>
        <translation type="vanished">Dies ist die Dauer des Grundschlags.
Die Werte sind 1, 2, 4, 8, 16, 32 und 64.
Es ist der Nenner der Taktart-Spezifikation.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:162</name>
    <message>
        <source>Whole</source>
        <translation type="vanished">Ganze</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:165</name>
    <message>
        <source>Half</source>
        <translation type="vanished">Halbe</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:168</name>
    <message>
        <source>Quarter</source>
        <translation type="vanished">Viertel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:171</name>
    <message>
        <source>Eighth</source>
        <translation type="vanished">Achtel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:174</name>
    <message>
        <source>Sixteenth</source>
        <translation type="vanished">Sechzehntel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:177</name>
    <message>
        <source>Thirty-Second</source>
        <translation type="vanished">Zweiundreissigstel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:18</name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Entfernen</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:180</name>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="vanished">Vierundsechzigstel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:183</name>
    <message>
        <source>Weak</source>
        <translation type="vanished">Schwach</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:186</name>
    <message>
        <source>Strong</source>
        <translation type="vanished"> Stark</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:189</name>
    <message>
        <source>Volume</source>
        <translation type="vanished">Volumen</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:192</name>
    <message>
        <source>Pan</source>
        <translation type="vanished">Balance</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:195</name>
    <message>
        <source>This is the velocity of the weak notes in the automatic rhythm pattern (all of them, except the first one)</source>
        <translation type="vanished">Dies ist die Lautstärke der schwachen Noten im Rhythmusschema (alle von ihnen, ausser der ersten)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:198</name>
    <message>
        <source>This is the velocity of the strong note in the automatic rhythm pattern (the first one)</source>
        <translation type="vanished">Dies ist die Lautstärke der starken Note im Rhythmusschema (die erste)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:201</name>
    <message>
        <source>This is the MIDI volume control (CC7)</source>
        <translation type="vanished">Dies ist die MIDI Lautstärkenregelung (CC7)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:204</name>
    <message>
        <source>This is the MIDI pan control (CC10)</source>
        <translation type="vanished">Dies ist die MIDI Balance Steuerung (CC10)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:207</name>
    <message>
        <source>This is the musical name of the tempo value</source>
        <translation type="vanished">Dies ist der musikalische Name des Tempos</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:21</name>
    <message>
        <source>Rows:</source>
        <translation type="vanished">Zeilen:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:210</name>
    <message>
        <source>The current &lt;i&gt;tempo&lt;/i&gt; value</source>
        <translation type="vanished">Der aktuelle Wert für das &lt;i&gt;Tempo&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:213</name>
    <message>
        <source>Tempo (in quarters per minute)</source>
        <translation type="vanished">Tempo (in Viertel pro Minute)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:216</name>
    <message>
        <source>This slider changes the &lt;i&gt;tempo&lt;/i&gt;, or speed of the rhythm.
Values are 25 to 250 quarters per minute (&lt;i&gt;Maelzel Metronome units&lt;/i&gt;).</source>
        <translation type="vanished">Dieser Schieberegler ändert das &lt;i&gt;Tempo&lt;/i&gt;, oder Geschwindigkeit des Rhythmus.
Die Werte sind von 25 bis 250 Viertel pro Minute (&lt;i&gt;Maelzel Metronom Einheiten&lt;/i&gt;).</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:220</name>
    <message>
        <source>If this checkbox is activated, the the program will remember the connections for the input and output ports, and try to reconnect them at program startup.</source>
        <translation type="vanished">Aktivieren Sie dieses Ankreuzfeld, damit das Programm sich an den Eingangs- und Ausgangs-Port erinnert, und diese beim nächsten Programmstart wieder verbindet.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:223</name>
    <message>
        <source>Automatic ports connection on startup</source>
        <translation type="vanished">Automatische Verbindung der Ports beim Start</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:226</name>
    <message>
        <source>Optional input port conn:</source>
        <translation type="vanished">Opt.Verbindung Eingangs-Port:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:229</name>
    <message>
        <source>This is the optional connection for the MIDI IN port.</source>
        <translation type="vanished">Dies ist die optionale Verbindung für den MIDI Eingangs-Port</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:232</name>
    <message>
        <source>Output port connection:</source>
        <translation type="vanished">Verbindung für Ausgabe-Port:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:235</name>
    <message>
        <source>This is the mandatory connection for the MIDI OUT port</source>
        <translation type="vanished">Dies ist die notwendige Verbindung für den MIDI Ausgabe-Port</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:238</name>
    <message>
        <source>Output instrument:</source>
        <translation type="vanished">Ausgabe Instrument:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:24</name>
    <message>
        <source>Use this button to add new rows (sounds) to the current pattern definition</source>
        <translation type="vanished">Dieser Knopf fügt der aktuellen Definition des Rhythmusschemas neue Zeilen (Töne) hinzu</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:241</name>
    <message>
        <source>This is the definition of the instrument connected to the MIDI OUT port</source>
        <translation type="vanished">Dies ist die Definition des Instrumentes das mit dem MIDI Ausgabe-Port verbunden ist</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:244</name>
    <message>
        <source>Bank:</source>
        <translation type="vanished">Bank:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:247</name>
    <message>
        <source>This is the Bank of the selected MIDI program</source>
        <translation type="vanished">Dies ist die Bank des ausgewählten MIDI Programms</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:250</name>
    <message>
        <source>Channel:</source>
        <translation type="vanished">Kanal:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:253</name>
    <message>
        <source>This is the MIDI channel, between 1 and 16. 
General MIDI uses the channel 10 for percussion sounds.</source>
        <translation type="vanished">Dies ist der MIDI Kanal, zwischen 1 und 16. 
Allgemeines MIDI braucht den Kanal 10 für das Schlagzeug.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:257</name>
    <message>
        <source>Program:</source>
        <translation type="vanished">Programm:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:260</name>
    <message>
        <source>This is the MIDI program</source>
        <translation type="vanished">Dies ist das MIDI Programm</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:263</name>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Auflösung:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:266</name>
    <message>
        <source>This is the MIDI time resolution (number of ticks in a quarter note)</source>
        <translation type="vanished">Dies ist die MIDI Zeitauflösung (Anzahl Ticks in einer Viertel Note)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:269</name>
    <message>
        <source>Weak note:</source>
        <translation type="vanished">Schwache Note:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:27</name>
    <message>
        <source>Add</source>
        <translation type="vanished">Hinzufügen</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:272</name>
    <message>
        <source>This is the sound of the weak notes for the automatic patterns</source>
        <translation type="vanished">Dies ist die Lautstärke der schwachen Note im automatischen Rhythmusschema</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:275</name>
    <message>
        <source>Note duration:</source>
        <translation type="vanished">Dauer der Note:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:278</name>
    <message>
        <source>This is the note duration in ticks, when using NOTE OFF events</source>
        <translation type="vanished">Dies ist die Dauer der Note in Anzahl Ticks, wenn NOTE OFF Ereignisse benutzt werden.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:281</name>
    <message>
        <source>Strong note:</source>
        <translation type="vanished">Starke Note:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:284</name>
    <message>
        <source>This is the sound of the strong notes for the automatic patterns</source>
        <translation type="vanished">Dies ist die Lautstärke der starken Note im automatischen Rhythmusschema</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:287</name>
    <message>
        <source>Optional setting to send NOTE OFF events</source>
        <translation type="vanished">Optionale Einstellung zum Senden von NOTE OFF Ereignissen</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:290</name>
    <message>
        <source>Send NOTE OFF events</source>
        <translation type="vanished">Sende NOTE OFF Ereignisse</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:293</name>
    <message>
        <source>If this option is activated, the knobs are drawn using a custom style</source>
        <translation type="vanished">Beim Aktivieren dieser Option werden die Knöpfe mit einem benutzerdefinierten Stil dargestellt</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:296</name>
    <message>
        <source>Styled Knobs</source>
        <translation type="vanished">Stilvolle Knöpfe</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:297</name>
    <message>
        <source>Your names</source>
        <translation type="vanished">Rene Landert</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:298</name>
    <message>
        <source>Your emails</source>
        <translation type="vanished">rene.landert@bluewin.ch </translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:3</name>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Rhythmusschema:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:30</name>
    <message>
        <source>Use this button to remove the selected row (sound) from the pattern definition</source>
        <translation type="vanished">Dieser Knopf  entfernt die ausgewählte Zeile (Töne) aus der Definition des Rhythmusschemas</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:33</name>
    <message>
        <source>Remove</source>
        <translation type="vanished">Entfernen</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:36</name>
    <message>
        <source>Beats:</source>
        <translation type="vanished">Taktzahl:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:39</name>
    <message>
        <source>Highligh the grid columns while playing</source>
        <translation type="vanished">Markiere die Gitterspalten während der Wiedergabe</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:42</name>
    <message>
        <source>Highlight
Columns</source>
        <translation type="vanished">Markiere
Spalten</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:46</name>
    <message>
        <source>This is the current beat number</source>
        <translation type="vanished">Dies ist die aktuelle Anzahl Grundschläge</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:49</name>
    <message>
        <source>This is the pattern table, beats as columns and sounds as rows</source>
        <translation type="vanished">Dies ist die Tabelle des Rhythmusschemas, Grundschläge als Spalten und Töne als Zeilen</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:52</name>
    <message>
        <source>Number of beats per measure (bar)</source>
        <translation type="vanished">Anzahl Grundschläge pro Takt</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:55</name>
    <message>
        <source>This is the beat length for the pattern column.</source>
        <translation type="vanished">Dies ist die Dauer des Grundschlags für die Spalte des Rhythmusschemas.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:58</name>
    <message>
        <source>Whole</source>
        <translation type="vanished">Ganze</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:6</name>
    <message>
        <source>Type a new name and press the &quot;Save&quot; button to create a new pattern, or choose an existing pattern from the drop-down list.</source>
        <translation type="vanished">Geben Sie einen neuen Namen ein und drücken Sie den Knopf &quot;Speichern&quot;, um ein neues Rhythmusschemas zu erstellen, oder  wählen Sie ein vorhandenes Schema aus der Aufklappliste.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:61</name>
    <message>
        <source>Half</source>
        <translation type="vanished">Halbe</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:64</name>
    <message>
        <source>Quarter</source>
        <translation type="vanished">Viertel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:67</name>
    <message>
        <source>Eighth</source>
        <translation type="vanished">Achtel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:70</name>
    <message>
        <source>Sixteenth</source>
        <translation type="vanished">Sechzehntel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:73</name>
    <message>
        <source>Thirty-Second</source>
        <translation type="vanished">Zweiundreissigstel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:76</name>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="vanished">Vierundsechzigstel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:79</name>
    <message>
        <source>This button starts playing the current pattern</source>
        <translation type="vanished">Dieser Knopf startet die Wiedergabe des Rhythmusschemas</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:82</name>
    <message>
        <source>Play</source>
        <translation type="vanished">Wiedergabe</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:85</name>
    <message>
        <source>This button stops the playback</source>
        <translation type="vanished">Dieser Knopf beendet die Wiedergabe</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:88</name>
    <message>
        <source>Stop</source>
        <translation type="vanished">Stopp</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:9</name>
    <message>
        <source>This button stores the current pattern definition with the name given</source>
        <translation type="vanished">Dieser Knopf speichert die aktuelle Definition des Rhythmusschemas mit dem gegebenen Namen</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:91</name>
    <message>
        <source>QPM: quarters per minute</source>
        <translation type="vanished">QPM: Tempo (in Viertel pro Minute)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:94</name>
    <message>
        <source>QPM:</source>
        <translation type="vanished">QPM:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:97</name>
    <message>
        <source>This is the current tempo in quarters per minute</source>
        <translation type="vanished">Dies ist das aktuelle Tempo in Viertel pro Minute</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:278</name>
    <message>
        <source>Do you want to remove the current pattern?</source>
        <translation type="vanished">Möchten Sie das aktuelle Rhythmusschema entfernen?</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:279</name>
    <message>
        <source>Remove Pattern</source>
        <translation type="vanished">Rhythmusschema entfernen</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:333</name>
    <message>
        <source>Sample Pattern</source>
        <translation type="vanished">Muster für Rhythmusschema</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:364</name>
    <message>
        <source>Insert Pattern Row</source>
        <translation type="vanished">Zeile in Rhythmusschema einfügen</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:365</name>
    <message>
        <source>Drum Key:</source>
        <translation type="vanished">Schlagzeug Taste:</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:386</name>
    <message>
        <source>Please select one, and only one row</source>
        <translation type="vanished">Bitte wählen Sie eine, und nur eine Zeile aus</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:388</name>
    <message>
        <source>Do you want to remove the selected pattern row?</source>
        <translation type="vanished">Möchten Sie die ausgewählte Zeile des Rhythmusschemas entfernen?</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:389</name>
    <message>
        <source>Remove Row</source>
        <translation type="vanished">Zeile entfernen</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:51</name>
    <message>
        <source>Pattern Editor</source>
        <translation type="vanished">Editor für Rhythmusschema</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:67</name>
    <message>
        <source>Cut</source>
        <translation type="obsolete">
            </translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:68</name>
    <message>
        <source>Copy</source>
        <translation type="obsolete">
            </translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:69</name>
    <message>
        <source>Paste</source>
        <translation type="obsolete">Rhythmusschema</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:114</name>
    <message>
        <source>Play/Stop</source>
        <translation type="vanished">Wiedergabe/Stopp</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:118</name>
    <message>
        <source>Show Action Buttons</source>
        <translation type="vanished">Aktionsknopf anzeigen</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:125</name>
    <message>
        <source>Patterns</source>
        <translation type="vanished">Rhythmusschema</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:130</name>
    <message>
        <source>Import Patterns</source>
        <translation type="vanished">Rhythmusschema importieren</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:135</name>
    <message>
        <source>Export Patterns</source>
        <translation type="vanished">Rhythmusschema exportieren</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:497</name>
    <message>
        <source>*.pat|Pattern Files (*.pat)</source>
        <translation type="vanished">*.pat|Rhythmusschema Dateien (*.pat)</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:498</name>
    <message>
        <source>Import Patterns</source>
        <translation type="vanished">Rhythmusschema importieren</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:510</name>
    <message>
        <source>*.pat|Pattern Files (*.pat)</source>
        <translation type="vanished">*.pat|Rhythmusschema Dateien (*.pat)</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:511</name>
    <message>
        <source>Export Patterns</source>
        <translation type="vanished">Rhythmusschema exportieren</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:527</name>
    <message>
        <source>Patterns</source>
        <translation type="vanished">Rhythmusschema</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:87</name>
    <message>
        <source>Fatal error from the ALSA sequencer. This usually happens when the kernel doesn&apos;t have ALSA support, or the device node (/dev/snd/seq) doesn&apos;t exists, or the kernel module (snd_seq) is not loaded. Please check your ALSA/MIDI configuration. Returned error was: %1</source>
        <translation type="vanished">Schwerer Fehler im ALSA-Sequenzer. Dies geschieht meist, wenn der Kernel kein ALSA unterstützt, oder das Gerät (/dev/snd/seq) nicht existiert, oder das Kernel-Modul (snd_seq) nicht geladen ist. Bitte überprüfen Sie Ihre ALSA/MIDI Konfiguration. Zurückgegebener Fehler war: %1</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:93</name>
    <message>
        <source>Error</source>
        <translation type="vanished">Fehler</translation>
    </message>
</context>
<context>
    <name>src/kmetronomeview.cpp:145</name>
    <message>
        <source>Tempo</source>
        <translation type="vanished">Tempo</translation>
    </message>
    <message>
        <source>Enter new Tempo:</source>
        <translation type="vanished">Neues Tempo eingeben:</translation>
    </message>
</context>
<context>
    <name>src/kmetronomeview.cpp:179</name>
    <message>
        <source>Automatic</source>
        <translation type="vanished">Automatisch</translation>
    </message>
</context>
<context>
    <name>src/kmetropreferences.cpp:29</name>
    <message>
        <source>Preferences</source>
        <translation type="vanished">Einstellungen</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:29</name>
    <message>
        <source>KDE MIDI metronome using ALSA sequencer</source>
        <translation type="vanished">KDE MIDI Metronom mit dem ALSA Sequenzer</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:41</name>
    <message>
        <source>KMetronome</source>
        <translation type="vanished">KMetronome</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:43</name>
    <message>
        <source>(C) 2005-2012 Pedro Lopez-Cabanillas</source>
        <translation type="vanished">(C) 2005-2012 Pedro Lopez-Cabanillas</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:45</name>
    <message>
        <source>Pedro Lopez-Cabanillas</source>
        <translation type="vanished">Pedro Lopez-Cabanillas</translation>
    </message>
</context>
<context>
    <name>src/sequenceradapter.cpp:65</name>
    <message>
        <source>No connection</source>
        <translation type="vanished">Keine Verbindung</translation>
    </message>
</context>
</TS>
